import pytest
from RiteshSum import doSum

test_data = [(10, 20, 30), (-1, -2, -3), (78, 100, 178)]


@pytest.mark.parametrize("number1,number2,expected", test_data)
def test_sum_functionality(number1, number2, expected):
    assert doSum(number1, number2) == expected



from setuptools import setup, find_packages
import os

VERSION = '0.0.2'
DESCRIPTION = 'Sum Example for Packaging Practice'

# Setting up
setup(
    name="TanySumPkg",
    version=VERSION,
    author="Ritesh Patil",
    author_email="<patil.ritesh311@gmail.com>",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)